(function($){

	$(document).ready(function () {
	
		accommodations.init();
	});
	
	var accommodations = {

		init: function () {
		
			accommodations.bindGallery();
		
			if (window.accommodationIsSelfCatered) {
				$(".step1_controls").html($(".step1_controls_holder").html());
				$(".step1_controls").show();
				$(".step1_controls .datepicker_holder").addClass('accommodation_vacancy_datepicker');
				accommodations.populateAvailableStartDates(window.accommodationId, window.roomTypeId, window.currentMonth, window.currentYear, accommodations.initializeControls);
				accommodations.bindNextButton();
				accommodations.bindResetButton();
			} else {
				accommodations.bindSelectDatesButton();
			}

			$('.radio').bind('click.uniform',
				function (e) {
					if ($(this).find("span").hasClass('checked')) 
						$(this).find("input").attr('checked', true);
					else
						$(this).find("input").attr('checked', false);
				}
			);
						
			$('.accommodation-booking-form').validate({
			
				onkeyup: false,
				ignore: [],
				rules: {
				
					first_name: {
						required: true
					},
					last_name: "required",
					email: {
						required: true,
						email: true
					},
					confirm_email: {
						required: true,
						equalTo: "#email"
					},
					phone: "required",
					address: "required",
					town: "required",
					zip: "required",
					country: "required",
					selected_date_from: "required",
					selected_date_to: "required"					
				},
				invalidHandler: function(e, validator) {
				
					var errors = validator.numberOfInvalids();
					if (errors) {
						var message = errors == 1
							? window.formSingleError
							: window.formMultipleError.format(errors);
						$("div.error div p").html(message);
						$("div.error").show();
					} else {
						$("div.error").hide();
					}					
				},
				messages: {
				
					first_name: window.bookingFormFirstNameError,
					last_name: window.bookingFormLastNameError,
					email: window.bookingFormEmailError,
					confirm_email: {
						required: window.bookingFormConfirmEmailError1,
						equalTo: window.bookingFormConfirmEmailError2
					},
					phone: window.bookingFormPhoneError,
					address: window.bookingFormAddressError,
					town: window.bookingFormCityError,
					zip: window.bookingFormZipError,
					country: window.bookingFormCountryError,
					selected_date_from: window.bookingFormDatesError,
					selected_date_to: window.bookingFormDatesError					
				},
				submitHandler: function() { 
				
					accommodations.processBooking();					
				}				
			});
			
			$('#cancel-accommodation-booking').on('click', function(event) {
				
				accommodations.hideBookingForm();
				accommodations.showAccommodationScreen();
				event.preventDefault();				
			});
			
		},
		bindResetButton : function() {
			$('.book-accommodation-reset').unbind('click');
			$('.book-accommodation-reset').on('click', function(event) {

				event.preventDefault();
				$('.book-accommodation-select-dates').show();
				window.roomTypeId = 0;
				$("#date_from_text").html("");
				$("#selected_date_from").val("");
				$("#date_to_text").html("");
				$("#selected_date_to").val("");							
				$(".dates_row").hide();
				$(".price_row").hide();
				$('.bf_room_type_row').hide();
				$('.booking-commands').hide();
				
				accommodations.populateAvailableStartDates(window.accommodationId, window.roomTypeId, window.currentMonth, window.currentYear, accommodations.refreshDatePicker);
				
			});
		},
		bindGallery : function() {
		
			$("#gallery").lightSlider({
				slideWidth:850,
				gallery:true,
				thumbWidth:100,
				thumbMargin:6.25,
				minSlide:1,
				maxSlide:1,
				auto:true,
				mode:'slide',
				proportion:'100%',
				onSliderLoad: function() {
					$('#gallery').removeClass('cS-hidden');
				}  
			});
		},
		bindSelectDatesButton : function () {
		
			$('.book-accommodation-select-dates').unbind('click');
			$('.book-accommodation-select-dates').on('click', function(event) {
				
				event.preventDefault();
				$('.book-accommodation-select-dates').show();
				$(this).hide();
				
				$('#wait_loading').show();
				
				var prevRoomTypeId = window.roomTypeId;
				
				$("#date_from_text").html("");
				$("#selected_date_from").val("");
				$("#date_to_text").html("");
				$("#selected_date_to").val("");							
				$(".dates_row").hide();
				$(".price_row").hide();
				$('.bf_room_type_row').hide();
				$('.booking-commands').hide();
				
				var buttonId = $(this).attr('id');
				window.roomTypeId = buttonId.replace('book-accommodation-', '');

				if (prevRoomTypeId > 0) {
					$('.accommodation_vacancy_datepicker').datepicker('destroy');
					$("#room_type_" + prevRoomTypeId + " .step1_controls").html('');
					$("#room_type_" + prevRoomTypeId + " .step1_controls").show();
				} 

				$("#room_type_" + window.roomTypeId + " .step1_controls").html($(".step1_controls_holder").html());
				$("#room_type_" + window.roomTypeId + " .step1_controls").show();
				
				$("#room_type_" + window.roomTypeId + " .step1_controls .datepicker_holder").addClass('accommodation_vacancy_datepicker');
				
				accommodations.populateAvailableStartDates(window.accommodationId, window.roomTypeId, window.currentMonth, window.currentYear, accommodations.initializeControls);
				
				accommodations.bindNextButton();
				accommodations.bindResetButton();
			});

		},
		bindNextButton : function () {

			$('.book-accommodation-next').unbind('click');
			$('.book-accommodation-next').on('click', function(event) {

				event.preventDefault();
				$('#wait_loading').show();
								
				var children = $('#booking_form_children').val();
				if (!children)
					children = 0;
					
				var adults = $('#booking_form_adults').val();
				if (!adults)
					adults = 0;
								
				$('.step_1_adults_holder').html(adults);
				$('.step_1_children_holder').html(children);
				if (window.roomTypeId > 0) {
					$('.step_1_room_type_holder').html('');
					$('.step_1_room_type_holder').html($('#room_type').html());
				}
				$('.step_1_date_from_holder').html($('#date_from_text').html());
				$('.step_1_date_to_holder').html($('#date_to_text').html());
				$('.step_1_total_holder').html($('.total_price').html());
				
				accommodations.showBookingForm();
				$('body,html').animate({
					scrollTop: 0
				}, 800);
					
				$('#wait_loading').hide();
			});
			
		},
		initializeControls : function() {
		
			accommodations.bindDatePicker();
			
			$('.bf_room_type_row').hide();
			$('.booking-commands').hide();

			if (window.roomTypeId > 0) {
				$('.bf_room_type_cell').show();
				$('#room_type').html($('li#room_type_' + roomTypeId + ' .room_type h2').html());
			} else {
				$('.bf_room_type_cell').hide();
			}			

			accommodations.bindControls(window.accommodationId, window.roomTypeId);
			
			$('#wait_loading').hide();		
		},
		refreshDatePicker : function() {
		
			if (typeof $('.accommodation_vacancy_datepicker') !== 'undefined') {
				$('.accommodation_vacancy_datepicker').datepicker( "refresh" );
			}
			$('#wait_loading').hide();	
		},
		bindDatePicker : function() {	

			if (typeof $('.accommodation_vacancy_datepicker') !== 'undefined') {

				$('.accommodation_vacancy_datepicker').datepicker({
					dateFormat: window.datepickerDateFormat,
					numberOfMonths: 1,
					hourMin: 6,
					hourMax: 18,
					minDate: 0,
					beforeShowDay: function(d) {

						var dUtc = Date.UTC(d.getFullYear(), d.getMonth(), d.getDate());
						
						var selectedTimeFrom = null;
						var selectedTimeTo = null;
						
						if ($("#selected_date_from").val()) {
							selectedTimeFrom = parseInt($("#selected_date_from").val());
						}
						if ($("#selected_date_to").val()) {
							selectedTimeTo = parseInt($("#selected_date_to").val());
						}

						if (window.accommodationVacancyDays) {
							var dateTextForCompare = d.getFullYear() + '-' + ("0" + (d.getMonth() + 1)).slice(-2) + '-' + ("0" + d.getDate()).slice(-2);
							
							if (selectedTimeFrom && dUtc == selectedTimeFrom)
								return [true, 'dp-highlight'];								
							if ($.inArray(dateTextForCompare, window.accommodationVacancyDays) == -1)
								return [false, 'ui-datepicker-unselectable ui-state-disabled'];
						}
						
						return [true, selectedTimeFrom && ((dUtc == selectedTimeFrom) || (selectedTimeTo && dUtc >= selectedTimeFrom && dUtc <= selectedTimeTo)) ? "dp-highlight" : ""];
					},
					onSelect: function(dateText, inst) {
					
						$('.booking-commands').hide();
					
						var selectedUtcTime = Date.UTC(inst.currentYear, inst.currentMonth, inst.currentDay);
					
						var selectedUtcDate = new Date(selectedUtcTime);
						
						window.selectedDateFrom = null;
						if ($("#selected_date_from").val()) {
							window.selectedDateFrom = new Date(parseInt($("#selected_date_from").val()));
						}
						window.selectedDateTo = null;
						if ($("#selected_date_to").val()) {
							window.selectedDateTo = new Date(parseInt($("#selected_date_to").val()));
						}
						
						if (!window.selectedDateFrom || window.selectedDateTo || (window.selectedDateFrom.toString() === selectedUtcDate.toString())) {
							
							$('#wait_loading').show();	
							$("#date_from_text").html(dateText);
							$("#selected_date_from").val(selectedUtcTime);
							window.selectedDateFrom = new Date(parseInt($("#selected_date_from").val()));
							$("#date_to_text").html("");
							$("#selected_date_to").val("");
							$(".dates_row").hide();
							$(".dates_row_from").show();
							$('.bf_room_type_row').hide();
							$(".price_row").hide();
							
							window.currentYear = inst.currentYear;
							window.currentMonth = (inst.currentMonth + 1);
							window.currentDay = inst.currentDay;
							var selectedFromDate = window.selectedDateFrom.getFullYear() + "-" + (window.selectedDateFrom.getMonth() + 1) + "-" + window.selectedDateFrom.getDate();
							accommodations.populateAvailableEndDates(selectedFromDate, window.accommodationId, window.roomTypeId, window.currentYear, window.currentMonth, window.currentDay, accommodations.rebindEndDates);
							
						} else {
						
							if (selectedUtcDate < window.selectedDateFrom)
							{
								$("#date_from_text").html(dateText);
								$("#selected_date_from").val(selectedUtcTime);
								window.selectedDateFrom = new Date(parseInt($("#selected_date_from").val()));
								$("#date_to_text").html("");
								$("#selected_date_to").val("");							
								$(".dates_row").hide();
								$(".dates_row_from").show();
								$('.bf_room_type_row').hide();
								$(".price_row").hide();

							}
							else
							{
								var vacancyDatesOk = true;
								for (var d = window.selectedDateFrom; d <= window.selectedDateTo; d.setDate(d.getDate() + 1)) {
									var tempDate = d.getFullYear() + '-' + ("0" + (d.getMonth() + 1)).slice(-2) + '-' +  ("0" + d.getDate()).slice(-2);
									if ($.inArray(tempDate, window.accommodationVacancyDays) == -1)
										vacancyDatesOk = false;
								}
								
								if (!vacancyDatesOk) {
									$("#date_from_text").html(dateText);
									$("#selected_date_from").val(selectedUtcTime);
									window.selectedDateFrom = new Date(parseInt($("#selected_date_from").val()));
									$("#date_to_text").html("");
									$("#selected_date_to").val("");									
									$(".dates_row").hide();
									$(".price_row").hide();
								} else {
								
									var totalDays = accommodations.diffDays(new Date(parseInt($("#selected_date_from").val())), new Date(selectedUtcTime));
									
									if (totalDays >= window.accommodationMinDaysStay || window.accommodationMinDaysStay == 0) {
									
										$("div.error.step1_error div p").html('');
										$("div.error.step1_error").hide();
									
										$("#date_to_text").html(dateText);
										$("#selected_date_to").val(selectedUtcTime);
										$(".dates_row_to").show();
										$('.bf_room_type_row').show();
										
										window.selectedDateFrom = new Date(parseInt($("#selected_date_from").val()));
										window.selectedDateTo = new Date(parseInt($("#selected_date_to").val()));
										
										if (window.selectedDateFrom == window.selectedDateTo) {
											window.selectedDateTo.setDate(window.selectedDateFrom.getDate() + 1);
											var temp = window.selectedDateTo.getFullYear() + '-' + ("0" + (window.selectedDateTo.getMonth() + 1)).slice(-2) + '-' +  ("0" + window.selectedDateTo.getDate()).slice(-2);
											$("#selected_date_to").val(window.selectedDateTo.valueOf());
											$("#date_to_text").html(temp);
										}
										
										accommodations.bindRatesTable();
									} else {
										$("div.error.step1_error div p").html(window.minDaysStayError);
										$("div.error.step1_error").show();
									}
								}
							}
						}
					},
					onChangeMonthYear: function (year, month, inst) {
						$('#wait_loading').show();
						window.currentMonth = month;
						window.currentYear = year;
						if (window.selectedDateFrom) {
							var selectedFromDate = window.selectedDateFrom.getFullYear() + "-" + (window.selectedDateFrom.getMonth() + 1) + "-" + window.selectedDateFrom.getDate();
							accommodations.populateAvailableEndDates(selectedFromDate, window.accommodationId, window.roomTypeId, window.currentYear, window.currentMonth, window.currentDay, accommodations.refreshDatePicker);
						} else {
							accommodations.populateAvailableStartDates(window.accommodationId, window.roomTypeId, window.currentMonth, window.currentYear, accommodations.refreshDatePicker);
						}
					}
				});
			}		
		},
		rebindEndDates : function() {

			if (typeof $('.accommodation_vacancy_datepicker') !== 'undefined') {

				if (window.accommodationVacancyDays.length == 0) {
				
					$("#date_from_text").html("");
					$("#selected_date_from").val("");
					$("#date_to_text").html("");
					$("#selected_date_to").val("");							
					$(".dates_row").hide();
					$(".price_row").hide();
				
					accommodations.populateAvailableStartDates(window.accommodationId, window.roomTypeId, window.currentMonth, window.currentYear, accommodations.refreshDatePicker);
				
				}
				$('.accommodation_vacancy_datepicker').datepicker( "refresh" );
			
			}
			$('#wait_loading').hide();		
		},
		processBooking : function() {
		
			$('#wait_loading').show();
			
			var dateFrom = window.selectedDateFrom.getFullYear() + "-" + (window.selectedDateFrom.getMonth() + 1) + "-" + window.selectedDateFrom.getDate(); 
			var dateTo = window.selectedDateTo.getFullYear() + "-" + (window.selectedDateTo.getMonth() + 1) + "-" + window.selectedDateTo.getDate(); 
			
			if (!window.roomTypeId)
				window.roomTypeId = 0;
				
			var firstName = $('#first_name').val();
			var lastName = $('#last_name').val();
			var email = $('#email').val();
			var phone = $('#phone').val();
			var address = $('#address').val();
			var town = $('#town').val();
			var zip = $('#zip').val();
			var country = $('#country').val();
			var requirements = $('#requirements').val();
			
			var roomCount = $('#room_count').val();
			if (!roomCount)
				roomCount = 1;
			
			var adults = $('#booking_form_adults').val();
			if (!adults)
				adults = 1;
				
			var children = $('#booking_form_children').val();
			if (!children)
				children = 0;
				
			var cValS = $('#c_val_s_acc').val();
			var cVal1 = $('#c_val_1_acc').val();
			var cVal2 = $('#c_val_2_acc').val();

			$("#confirm_first_name").html(firstName);
			$("#confirm_last_name").html(lastName);
			$("#confirm_email_address").html(email);
			$("#confirm_phone").html(phone);
			$("#confirm_street").html(address);
			$("#confirm_town").html(town);
			$("#confirm_zip").html(zip);
			$("#confirm_country").html(country);
			$("#confirm_requirements").html(requirements);
			$("#confirm_adults").html(adults);
			$("#confirm_children").html(children);
			$("#confirm_date_from").html(dateFrom);
			$("#confirm_date_to").html(dateTo);
			
			$.ajax({
				url: BYTAjax.ajaxurl,
				data: {
					'action':'book_accommodation_ajax_request',
					'first_name' : firstName,
					'last_name' : lastName,
					'email' : email,
					'phone' : phone,
					'address' : address,
					'town' : town,
					'zip' : zip,
					'country' : country,
					'special_requirements' : requirements,
					'date_to' : dateTo,
					'date_from' : dateFrom,
					'accommodation_id' : window.accommodationId,
					'room_type_id' : window.roomTypeId,
					'room_count' : roomCount,
					'c_val_s' : cValS,
					'c_val_1' : cVal1,
					'c_val_2' : cVal2,
					'adults' : adults,
					'children' : children,
					'nonce' : BYTAjax.nonce
				},
				success:function(data) {
				
					// This outputs the result of the ajax request
					if (data == 'captcha_error') {
					
						$("div.error div p").html(window.invalidCaptchaMessage);
						$("div.error").show();
					} else {
					
						var returnedId = data;
						$("div.error div p").html('');
						$("div.error").hide();
						
						var isReservationOnly = accommodations.getAccommodationIsReservationOnly(window.accommodationId);
						
						if (window.useWoocommerceForCheckout && window.wooCartPageUri.length > 0 && !isReservationOnly) {
						
							accommodations.addAccProdToCart(returnedId);
						} else {
						
							accommodations.hideBookingForm();
							accommodations.showConfirmationForm();
						}
					}
					
					$('#wait_loading').hide();
				},
				error: function(errorThrown){
				
					// console.log(errorThrown);
				}
			}); 
		},
		getAccommodationIsReservationOnly : function (accommodationId) {
			var isReservationOnly = 0;

			var dataObj = {
				'action':'accommodation_is_reservation_only_request',
				'accommodation_id' : accommodationId,
				'nonce' : BYTAjax.nonce
			}		

			$.ajax({
				url: BYTAjax.ajaxurl,
				data: dataObj,
				async: false,
				success:function(data) {
					// This outputs the result of the ajax request
					isReservationOnly = parseInt(data);
				},
				error: function(errorThrown){

				}
			});

			return isReservationOnly;
		},	
		addAccProdToCart : function (p_id) {
		
			$.get(window.siteUrl + '/?post_type=product&add-to-cart=' + p_id, function() {
				accommodations.accRedirectToCart();
			});
		},
		accRedirectToCart : function() {
		
			top.location.href = window.wooCartPageUri;
		},
		showBookingForm : function() {
		
			$('.accommodation-booking-form').show();
			$('.three-fourth .csSlideOuter').hide();
			$('.three-fourth .inner-nav').hide();
			$('.three-fourth .tab-content').hide();
		},
		hideBookingForm : function() {
		
			$('.accommodation-booking-form').hide();
		},			
		showConfirmationForm : function() {
		
			$('#accommodation-confirmation-form').show();
		},
		showAccommodationScreen : function() {
		
			$('.three-fourth .csSlideOuter').show();
			$('.three-fourth .inner-nav').show();
			$('.three-fourth .tab-content').show();
			$(".tab-content").hide();
			$(".tab-content:first").show();
			$(".inner-nav li:first").addClass("active");
		},
		bindRatesTable : function() {
			
			$(".dates_row").show();
			$(".price_row").show();

			$('table.breakdown thead').html('');
			$('table.breakdown tfoot').html('');
			$('table.breakdown tbody').html('');

			var room_count = $('#room_count').val();
			if (!room_count)
				room_count = 1;
			
			var adults = $('#booking_form_adults').val();
			if (!adults)
				adults = 1;
				
			var children = $('#booking_form_children').val();
			if (!children)
				children = 0;
			
			var headerRow = '<tr class="rates_head_row">';
			var colCount = 2;
			
			headerRow += '<th>' + window.dateLabel + '</th>';		
			
			if (window.accommodationIsPricePerPerson) {
			
				headerRow += '<th>' + window.adultCountLabel + '</th>';
				headerRow += '<th>' + window.pricePerAdultLabel + '</th>';
				headerRow += '<th>' + window.childCountLabel + '</th>';
				headerRow += '<th>' + window.pricePerChildLabel + '</th>';
				colCount = 6;
			} 
			headerRow += '<th>' + window.pricePerDayLabel + '</th>';		
			
			headerRow += '</tr>';

			$('table.breakdown thead').append(headerRow);	
			
			var footerRow = '<tr>';
			footerRow += '<th colspan="' + (colCount - 1) + '">' + window.priceTotalLabel + '</th>';
			footerRow += '<td class="total_price">' + accommodations.formatPrice(0) + '</td>';
			footerRow += '</tr>';
			$('table.breakdown tfoot').append(footerRow);
			
			if (window.selectedDateFrom && window.selectedDateTo) {
			
				$('#datepicker_loading').show();
				
				var fromTime = window.selectedDateFrom.valueOf();
				var toTime = window.selectedDateTo.valueOf();
			
				window.rateTableTotalRows = accommodations.diffDays(new Date(fromTime), new Date(toTime));
				
				window.rateTableTotalPrice = 0;
				window.rateTableRowIndex = 0;
				
				while (fromTime < toTime) {
					accommodations.buildRateRow(fromTime, adults, children, colCount);
					fromTime += 86400000;
				}
				
				$('.booking-commands').show();
			}			
		},
		formatPrice: function( price ) {
			if (window.currencySymbolShowAfter)
				return price + ' ' + window.currencySymbol;
			else
				return window.currencySymbol + ' ' + price;
		},
		diffDays : function( date1, date2) {
			return (
				Date.UTC(date2.getYear(), date2.getMonth(), date2.getDate()) -
				Date.UTC(date1.getYear(), date1.getMonth(), date1.getDate())
			) / 86400000;
		},
		bindControls : function (accommodation_id, room_type_id) {

			if ($('#booking_form_adults option').size() == 0) {
			
				var max_count = 0;
				var max_child_count = 0;
				
				if (room_type_id > 0) {
					max_count = $('li#room_type_' + room_type_id + ' .room-information .max_count').val();
					max_child_count = $('li#room_type_' + room_type_id + ' .room-information .max_child_count').val();
				} else {
					max_count = window.accommodationMaxCount;
					max_child_count = window.accommodationMaxChildCount;
				}
				
				if (!max_child_count)
					max_child_count = 0;
			
				for ( var i = 1; i <= max_count; i++ ) {
					$('<option ' + (i == 1 ? 'selected' : '') + '>').val(i).text(i).appendTo('#booking_form_adults');
				}
				
				$('#booking_form_adults').on('change', function (e) {
					accommodations.bindRatesTable();	
				});

				if (max_child_count > 0) {
					$('<option selected>').val(0).text(0).appendTo('#booking_form_children');
					for ( var i = 1; i <= max_child_count; i++ ) {
						$('<option>').val(i).text(i).appendTo('#booking_form_children');
					}
					
					$('#booking_form_children').on('change', function (e) {
						accommodations.bindRatesTable();
					});
				} else {
					$('.booking_form_children').hide();
				}
				
				$('#booking_form_adults').uniform();
				$('#booking_form_children').uniform();
				
			}
			
		},
		populateAvailableStartDates : function(accommodationId, roomTypeId, month, year, callDelegate) {
		
			var dateArray = new Array();

			var dataObj = {
				'action':'accommodation_available_start_dates_request',
				'accommodationId' : accommodationId,
				'roomTypeId' : roomTypeId,
				'month' : month,
				'year' : year,
				'nonce' : BYTAjax.nonce
			}		

			$.ajax({
				url: BYTAjax.ajaxurl,
				data: dataObj,
				success:function(json) {
					// This outputs the result of the ajax request
					var availableDates = JSON.parse(json);
					var i = 0;
					for (i = 0; i < availableDates.length; ++i) {
						dateArray.push(availableDates[i].single_date);
					}
					
					window.accommodationVacancyDays = dateArray;
					
					if (typeof(callDelegate) !== 'undefined') {
						callDelegate();
					}
				},
				error: function(errorThrown){
					console.log(errorThrown);
				}
			});

			return dateArray;
		},
		populateAvailableEndDates : function(startDate, accommodationId, roomTypeId, year, month, day, callDelegate) {
		
			var dateArray = new Array();

			var dataObj = {
				'action':'accommodation_available_end_dates_request',
				'accommodationId' : accommodationId,
				'roomTypeId' : roomTypeId,
				'startDate' : startDate,
				'year' : year,
				'month' : month,
				'day' : day,
				'nonce' : BYTAjax.nonce
			}		

			$.ajax({
				url: BYTAjax.ajaxurl,
				data: dataObj,
				success:function(json) {
				
					// This outputs the result of the ajax request
					var availableDates = JSON.parse(json);
					var i = 0;
					for (i = 0; i < availableDates.length; ++i) {
						dateArray.push(availableDates[i].single_date);
					}
					
					window.accommodationVacancyDays = dateArray;
					
					callDelegate();
				},
				error: function(errorThrown){
					console.log(errorThrown);
				}
			});

			return dateArray;
		},
		buildRateRow : function (fromTime, adults, children, colCount) {
		
			var price = 0;
			
			var d = new Date(fromTime);
			var day = d.getDate();
			var month = d.getMonth() + 1;
			var year = d.getFullYear();
			var dateValue = $.datepicker.formatDate('MM dd, yy', new Date(fromTime));
			// var dateValue = year + "-" + month + "-" + day; 

			var dataObj = {
				'action':'accommodation_get_price_request',
				'roomTypeId' : window.roomTypeId,
				'accommodationId' : window.accommodationId,
				'dateValue' : dateValue,
				'nonce' : BYTAjax.nonce
			}		

			$.ajax({
				url: BYTAjax.ajaxurl,
				data: dataObj,
				dataType: 'json',
				success:function(prices) {
				
					var tableRow = '';
					// This outputs the result of the ajax request
					window.rateTableRowIndex++;
					var pricePerDay = parseFloat(prices.price_per_day);
					var pricePerChild = 0;
					
					tableRow += '<tr>';
					tableRow += '<td>' + dateValue + '</td>';
					
					if (window.accommodationIsPricePerPerson) {
						pricePerChild = parseFloat(prices.child_price);
						tableRow += '<td>' + adults + '</td>';
						tableRow += '<td>' + accommodations.formatPrice(pricePerDay) + '</td>';
						tableRow += '<td>' + children + (window.accommodationCountChildrenStayFree > 0 ? ' *' : '') + '</td>';
						tableRow += '<td>' + accommodations.formatPrice(pricePerChild) + '</td>';
					} 
					
					if (window.accommodationIsPricePerPerson) {
						children = children - window.accommodationCountChildrenStayFree;
						children = children >= 0 ? children : 0;
						pricePerDay = (pricePerDay * adults) + (pricePerChild * children);
					} else {
						pricePerDay = pricePerDay;
					}
					
					window.rateTableTotalPrice += pricePerDay;
					
					$('.total_price').html(accommodations.formatPrice(window.rateTableTotalPrice));
					$("#confirm_total").html(accommodations.formatPrice(window.rateTableTotalPrice))
					
					tableRow += '<td>' + accommodations.formatPrice(pricePerDay) + '</td>';		
					
					tableRow += '</tr>';
					
					$('table.breakdown tbody').append(tableRow);
					
					if (window.rateTableRowIndex == window.rateTableTotalRows) {
						
						if ($("table.breakdown").data('tablesorter') == null) {
							$("table.breakdown").tablesorter({
								debug:false,
								dateFormat: window.datepickerDateFormat, //'ddmmyyyy',
								sortList: [[0,0]]
							});
						}
						
						$("table.breakdown").trigger("update");
						$("table.breakdown").trigger("sorton", [[[0,0]]]);

						$('#datepicker_loading').hide();
					}
				},
				error: function(errorThrown){
					console.log(errorThrown);
				}
			});
		
		}
	}
})(jQuery);